@@ -26,7 +26,8 @@ available_codon_tables_shortnames = {
 def csv_string_to_codons_dict(csv_string):
     """Transform a CSV string of a codon table to a dict."""
     result = {}
-    for line in csv_string.split("\n")[1:]:
+    csv_stripped = csv_string.rstrip()
+    for line in csv_stripped.split("\n")[1:]:
         aa, codon, freq = line.split(",")
         if aa not in result:
             result[aa] = {}
@@ -63,7 +64,7 @@ def get_codons_table(table_name, replace_U_by_T=True, web_timeout=5):
 
     Returns a dict {"*": {'TAA': 0.64...}, 'K': {'AAA': 0.76...}, ...}
 
-    
+
     """
     if replace_U_by_T:
         table = get_codons_table(table_name, replace_U_by_T=False, web_timeout=5)
